@@ -18,13 +18,13 @@ final class IsolatedTestRunnerRegistry
 {
     private static ?IsolatedTestRunner $runner = null;
 
-    public static function run(TestCase $test, bool $runEntireClass, bool $preserveGlobalState): void
+    public static function run(TestCase $test, bool $preserveGlobalState, bool $requiresXdebug): void
     {
         if (self::$runner === null) {
             self::$runner = new SeparateProcessTestRunner;
         }
 
-        self::$runner->run($test, $runEntireClass, $preserveGlobalState);
+        self::$runner->run($test, $preserveGlobalState, $requiresXdebug);
     }
 
     public static function set(IsolatedTestRunner $runner): void
