@@ -22,10 +22,9 @@ final readonly class CoversClassesThatExtendClass extends Metadata
     private string $className;
 
     /**
-     * @param int<0, 1>    $level
      * @param class-string $className
      */
-    protected function __construct(int $level, string $className)
+    protected function __construct(Level $level, string $className)
     {
         parent::__construct($level);
 
