@@ -9,6 +9,7 @@
  */
 namespace PHPUnit\Util;
 
+use function array_any;
 use function array_unshift;
 use function defined;
 use function in_array;
@@ -124,12 +125,9 @@ final readonly class Filter
      */
     private static function frameExists(array $trace, string $file, int $line): bool
     {
-        foreach ($trace as $frame) {
-            if (isset($frame['file'], $frame['line']) && $frame['file'] === $file && $frame['line'] === $line) {
-                return true;
-            }
-        }
-
-        return false;
+        return array_any(
+            $trace,
+            static fn (array $frame) => isset($frame['file'], $frame['line']) && $frame['file'] === $file && $frame['line'] === $line,
+        );
     }
 }
