@@ -11,10 +11,13 @@ namespace PHPUnit\Event\Test;
 
 use PHPUnit\Event\AbstractEventTestCase;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 
 #[CoversClass(PartialMockObjectCreated::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/events')]
 final class PartialMockObjectCreatedTest extends AbstractEventTestCase
 {
     public function testConstructorSetsValues(): void
