@@ -10,11 +10,14 @@
 namespace PHPUnit\Event\Code;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(ComparisonFailure::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/value-objects')]
 final class ComparisonFailureTest extends TestCase
 {
     public function testConstructorSetsValues(): void
