@@ -16,12 +16,15 @@ use function sys_get_temp_dir;
 use function tempnam;
 use function unlink;
 use PHPUnit\Framework\Attributes\CoversMethod;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 
 #[CoversMethod(Assert::class, 'assertFileIsReadable')]
 #[TestDox('assertFileIsReadable()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertFileIsReadableTest extends TestCase
 {
     private string $file;
