@@ -10,6 +10,7 @@
 namespace PHPUnit\Framework;
 
 use PHPUnit\Framework\Attributes\CoversMethod;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 use stdClass;
@@ -17,6 +18,8 @@ use stdClass;
 #[CoversMethod(Assert::class, 'assertObjectHasProperty')]
 #[TestDox('assertObjectHasProperty()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertObjectHasPropertyTest extends TestCase
 {
     public function testSucceedsWhenConstraintEvaluatesToTrue(): void
