@@ -14,6 +14,9 @@ use PHPUnit\Framework\Attributes\Medium;
 use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\MockObject\Generator\ClassIsEnumerationException;
 use PHPUnit\Framework\MockObject\Generator\ClassIsFinalException;
+use PHPUnit\Framework\MockObject\Generator\Generator;
+use PHPUnit\Framework\MockObject\Generator\InvalidMethodNameException;
+use PHPUnit\Framework\MockObject\Generator\MethodNamedMethodException;
 use PHPUnit\Framework\MockObject\Generator\UnknownTypeException;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\TestFixture\MockObject\AnInterface;
@@ -21,6 +24,7 @@ use PHPUnit\TestFixture\MockObject\Enumeration;
 use PHPUnit\TestFixture\MockObject\ExtendableClass;
 use PHPUnit\TestFixture\MockObject\ExtendableReadonlyClass;
 use PHPUnit\TestFixture\MockObject\FinalClass;
+use PHPUnit\TestFixture\MockObject\InterfaceWithMethodNamedMethod;
 
 #[Group('test-doubles')]
 #[Group('test-doubles/creation')]
@@ -83,4 +87,24 @@ final class CreateMockTest extends TestCase
 
         $this->createMock('this\does\not\exist');
     }
+
+    public function testCannotCreateMockObjectWithInvalidMethodName(): void
+    {
+        $this->expectException(InvalidMethodNameException::class);
+        $this->expectExceptionMessage('Cannot double method with invalid name "0"');
+
+        (new Generator)->testDouble(
+            AnInterface::class,
+            true,
+            ['0'],
+        );
+    }
+
+    public function testCannotCreateMockObjectForInterfaceWithMethodNamedMethod(): void
+    {
+        $this->expectException(MethodNamedMethodException::class);
+        $this->expectExceptionMessage('Doubling interfaces (or classes) that have a method named "method" is not supported.');
+
+        $this->createMock(InterfaceWithMethodNamedMethod::class);
+    }
 }
