@@ -778,6 +778,63 @@ EOT,
         $this->assertFalse($double->doSomething());
     }
 
+    public function testMethodNameMustBeConfiguredBeforeMethodParametersCanBeConfigured(): void
+    {
+        $double = $this->createMock(InterfaceWithReturnTypeDeclaration::class);
+
+        try {
+            $double->expects($this->once())->with(1);
+        } catch (MethodNameNotConfiguredException $e) {
+            $this->assertSame('Method name is not configured', $e->getMessage());
+
+            return;
+        } finally {
+            $this->resetMockObjects();
+        }
+
+        $this->fail();
+    }
+
+    public function testMethodParametersCanOnlyBeConfiguredOnce(): void
+    {
+        $double = $this->createMock(InterfaceWithReturnTypeDeclaration::class);
+
+        try {
+            $double->expects($this->once())->method('doSomethingElse')->with(1)->with(2);
+        } catch (MethodParametersAlreadyConfiguredException $e) {
+            $this->assertSame('Method parameters already configured', $e->getMessage());
+
+            return;
+        } finally {
+            $this->resetMockObjects();
+        }
+
+        $this->fail();
+    }
+
+    #[DoesNotPerformAssertions]
+    #[IgnorePhpunitDeprecations]
+    #[TestDox('with() can be used without expects() and is not verified when the method is not called')]
+    public function testWithCanBeUsedWithoutExpectsAndIsNotVerifiedWhenTheMethodIsNotCalled(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithReturnTypeDeclaration::class);
+
+        $double->method('doSomethingElse')->with(1)->willReturn(2);
+    }
+
+    #[IgnorePhpunitDeprecations]
+    #[TestDox('with() can be used without expects() and is verified when the method is called')]
+    public function testWithCanBeUsedWithoutExpectsAndIsVerifiedWhenTheMethodIsCalled(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithReturnTypeDeclaration::class);
+
+        $double->method('doSomethingElse')->with(1)->willReturn(2);
+
+        $this->expectException(ExpectationFailedException::class);
+
+        $double->doSomethingElse(0);
+    }
+
     /**
      * @param class-string $type
      */
